% BNSrates.m
% Generate plots for LIGO-T1000414
% "An Astrophysical Metric for LIGO Open Data Release"

clear all
close all

% high, realistic and low rates from Table 4 of LIGO-P0900125
rates = [10, 1, 0.3; 1, 0.03, 0.005 ; 0.01, 6e-4, 1e-4]*1.e-6;
% Replace BNS-low with BNS-realistic/10
% rates = [10, 1, 0.3; 1, 0.03, 0.005 ; 0.1, 6e-4, 1e-4]*1.e-6;
NSconsrate=0.1*1e-6;

% plotting marks and legend
mark = {'b--','g--','r--';'b','g','r';'b:','g:','r:'};
lege = {'NS-NS high','NS-BH high','BH-BH high', ...
       'NS-NS re','NS-BH re','BH-BH re', ...
       'NS-NS low','NS-BH low','BH-BH low', 'NS-NS cons'};
   
% Horizon distance for BNS, NS-BH, and BH-BH, from LIGO-P0900125
Dhorizon = [ 445, 927, 2187 ];
Vhorizon = 4./3.*pi*(Dhorizon/2.26).^3;
chirpmass = [(1.4*1.4)^0.6*(1.4+1.4)^(-0.2), (1.4*10)^0.6*(1.4+10)^(-0.2), (10*10)^0.6*(10+10)^(-0.2)]; 

% set defaults for plots
set(0,'DefaultLineLineWidth',2);
set(0,'DefaultTextFontSize',48);

figure(1)
days = logspace(1,3,100);
years = days/365;
for irate = 1:3,
    for ibin = 1:3,
        Nev = rates(irate,ibin)*Vhorizon(ibin)*years;
        loglog(days,Nev,char(mark(irate,ibin)),'LineWidth',2)
        hold on
    end
end
loglog(days, NSconsrate*Vhorizon(1)*years, 'm-','LineWidth', 3);
legend(lege);
xlabel('Observation time (days)');
ylabel('Expected number of detections')
%grid on
axis([days(1) days(end) 1e-3 1e4])
loglog([days(1) days(end)],[3 3],'k')
loglog([365 365],[1e-3 1e4],'k')
hold off
print -dpng AllDetections.png

figure(2)
Dh = logspace(1,4,100);
Vh = 4./3.*pi*(Dh/2.26).^3;
Ne = 3; %actually, -log(0.05)=2.9957
for irate = 1:3,
    for ibin = 1:3,
        T = Ne./(rates(irate,ibin)*Vh)*365;
        loglog(Dh,T,char(mark(irate,ibin)),'LineWidth',2)
        hold on
    end
end
loglog(Dh, Ne./(NSconsrate*Vh)*365, 'm-','LineWidth', 3);
legend(lege);
xlabel('Horizon distance for source type (Mpc)');
ylabel('Days required to get detection at 95% confidence')
%grid on
axis([Dh(1) Dh(end) 1e-3 1e9])
loglog([1 1e4],[365 365],'k')
loglog(Dhorizon(1)*[1 1],[1e-3 1e9],'b')
loglog(Dhorizon(2)*[1 1],[1e-3 1e9],'g')
loglog(Dhorizon(3)*[1 1],[1e-3 1e9],'r')
hold off
print -dpng TimeToDetection.png

figure(3)
VT = logspace(3,10,100);
for irate = 1:3,
    for ibin = 1:3,
        Nev = rates(irate,ibin)*VT;
        loglog(VT,Nev,char(mark(irate,ibin)),'LineWidth',2)
        hold on
    end
end
loglog(VT, NSconsrate*VT, 'm-','LineWidth', 3);
legend(lege);
xlabel('Average volume for source type (Mpc^3) * Time (yr)');
ylabel('Expected number of detections')
%grid on
axis([VT(1) VT(end) 1e-4 1e4])
loglog([VT(1) VT(end)],[3 3],'k')
loglog(Vhorizon(1)*[1 1],[1e-4 1e4],'b')
loglog(Vhorizon(2)*[1 1],[1e-4 1e4],'g')
loglog(Vhorizon(3)*[1 1],[1e-4 1e4],'r')
hold off
print -dpng DetectionVolume.png

figure(4)
VT = logspace(3,10,100);
for irate = 1:3,
    for ibin = 1:3,
        Nev = rates(irate,ibin)*VT*(chirpmass(ibin)/chirpmass(1))^(15/6);
        %(Dhorizon(ibin)/Dhorizon(1))^3;
        loglog(VT,Nev,char(mark(irate,ibin)),'LineWidth',2)
        hold on
    end
end
loglog(VT, NSconsrate*VT, 'm-','LineWidth', 3);
legend(lege);
xlabel('Average volume for BNS (Mpc^3) * Time (yr)');
ylabel('Expected number of detections')
%grid on
axis([VT(1) VT(end) 1e-4 1e4])
loglog([VT(1) VT(end)],[3 3],'k')
loglog(Vhorizon(1)*[1 1],[1e-4 1e4],'k')
hold off
print -dpng DetectionSensemonVolume.png
